package supperSlonic.amazonConnection;

import java.io.IOException;
import java.util.Properties;

import supperSlonic.amazonConnection.entities.ResultBase;

import com.amazonaws.auth.AWSCredentials;
import com.amazonaws.auth.BasicAWSCredentials;
import com.amazonaws.auth.InstanceProfileCredentialsProvider;

public class AmazonContext
{
	public static final String AWS_ACCESS_KEY_NAME = "supperSlonic.aws.key";
	public static final String AWS_SECRET_ACCESS_KEY_NAME = "supperSlonic.aws.secret_key";
	public static final String AWS_ENVIRONMENT_NAME = "supperSlonic.aws.environment";
	
	private String accessKey;
	private String secretAccessKey;
	private String enviroment = "";
	
	public AWSCredentials getCredentials()
	{
		if(this.isNullOrEmpty(this.accessKey) && this.isNullOrEmpty(this.secretAccessKey))
		{			
			return new InstanceProfileCredentialsProvider().getCredentials(); //try to get tmp credentials
		}
		else
		{			
			return new BasicAWSCredentials(this.accessKey, this.secretAccessKey);
		}
	}
	
	public void loadProperties(Properties contextProperties) throws IOException, IllegalArgumentException
	{
		ResultBase validationResult = this.isValidProperties(contextProperties);
		if (!validationResult.IsSuccess()) 
		{
            throw new IllegalArgumentException("The specified file is not a valid context properties file. " + validationResult.getErrorMessage());
        }
		
		readProperties(contextProperties);
	}
		
	protected void readProperties(Properties properties)
	{
		this.accessKey = properties.getProperty(AWS_ACCESS_KEY_NAME);
		this.secretAccessKey = properties.getProperty(AWS_SECRET_ACCESS_KEY_NAME);
		this.enviroment = properties.getProperty(AWS_ENVIRONMENT_NAME);
				
		System.out.println("Amazon enviroment: " + this.enviroment);
	}

	public ResultBase isValidProperties(Properties properties) 
	{
		ResultBase result = new ResultBase();
		
		if(properties == null)
		{
			result.setError(ErrorResults.PropertiesFileIsNullErrorCode, ErrorResults.PropertiesFileIsNullErrorMessage);
			return result;
		}
		
		if(properties.getProperty(AWS_ACCESS_KEY_NAME) == null)
		{
			result.setError(ErrorResults.MissingAccessKeyErrorCode, ErrorResults.MissingAccessKeyErrorMessage);
			return result;
		}
		
		if(properties.getProperty(AWS_SECRET_ACCESS_KEY_NAME) == null)
		{
			result.setError(ErrorResults.MissingSecretKeyErrorCode, ErrorResults.MissingSecretKeyErrorMessage);
			return result;
		}
		
		if(properties.getProperty(AWS_ENVIRONMENT_NAME) == null)
		{
			result.setError(ErrorResults.MissingEnviromentErrorCode, ErrorResults.MissingEnviromentErrorMessage);
			return result;
		}
		
		return result;
	}
	
	public String getAccessKey()
	{
		return this.accessKey;
	}

	public void setAccessKey(String value)
	{
		this.accessKey = value;
	}
	
	public String getSecretKey()
	{
		return this.secretAccessKey;
	}
	
	public void setSecretKey(String value)
	{
		this.secretAccessKey = value;
	}
	
	public String getEnviroment()
	{
		return this.enviroment;
	}
	
	public void setEnviroment(String value)
	{
		this.enviroment = value;
	}
	
	 @Override
    public String toString() {
        return "accessKey = " + this.accessKey
                + ", secretAccessKey = " + this.secretAccessKey
                + ", enviroment = " + this.enviroment;
    }
    
    @Override
    public boolean equals(Object obj)
    {
    	if (obj == null)
            return false;
    	
        if (obj == this)
            return true;
        
        if (obj.getClass() != getClass())
            return false;
        
        AmazonContext obj2 = (AmazonContext)obj;
        
        return (
        			this.accessKey.equals(obj2.getAccessKey()) &&
        			this.secretAccessKey.equals(obj2.getSecretKey()) &&
        			this.enviroment.equals(obj2.getEnviroment())
        		);
    }
    
    private boolean isNullOrEmpty(String value)
    {
    	if(value == null)
    		return true;
    	
    	if(value.trim().isEmpty())
    		return true;
    	
    	return false;
    }
}
